==> epiphany-2.26.1-i486-4gsb.tgz: install/doinst.sh <==
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany-fonts.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany-lockdown.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany-pango.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany.schemas >/dev/null 2>&1
fi
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

for i in gnome hicolor HighContrastLargePrint LowContrastLargePrint HighContrastLargePrintInverse;
do
    if [ -e usr/share/icons/$i/icon-theme.cache ]; then
        rm -f usr/share/icons/$i/icon-theme.cache
    fi
    usr/bin/gtk-update-icon-cache -f -q --ignore-theme-index usr/share/icons/$i
done

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi

==> epiphany-2.26.3-i486-1gsb.tgz: install/doinst.sh <==
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ca/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/cs/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/el/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/oc/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/ru/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-addressbar-smartbookmark-screenshot.png ephy-addressbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-history-window-screenshot.png ephy-history-window-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-bookmarkbar-smartbookmark-screenshot.png ephy-bookmarkbar-smartbookmark-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; rm -rf ephy-screenshot.png )
( cd usr/share/gnome/help/epiphany/en_GB/figures ; ln -sf ../../C/figures/ephy-screenshot.png ephy-screenshot.png )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany-fonts.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany-lockdown.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany-pango.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/epiphany.schemas >/dev/null 2>&1
fi
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

for i in gnome hicolor HighContrastLargePrint LowContrastLargePrint HighContrastLargePrintInverse;
do
    if [ -e usr/share/icons/$i/icon-theme.cache ]; then
        rm -f usr/share/icons/$i/icon-theme.cache
    fi
    usr/bin/gtk-update-icon-cache -f -q --ignore-theme-index usr/share/icons/$i 1>/dev/null 2>/dev/null
done

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi
